@@ -121,7 +121,7 @@ class Smart(Generic[T]):
     debug: bool = strutil.to_bool(os.getenv('SMARTPARAMS_DEBUG', default='no'))
 
     lab = SmartLab()
-    __register = SmartRegister()
+    register = SmartRegister()
 
     def __init__(
         self,
@@ -147,6 +147,9 @@ class Smart(Generic[T]):
         for key, value in kwargs.items():
             self.set(key, value)
 
+        if callable(smart_init := getattr(self._callable, '__smart_init__', None)):
+            smart_init(self)
+
     @property
     def type(self) -> Type[T]:
         return typeutil.get_return_type(self._callable)
@@ -155,10 +158,6 @@ class Smart(Generic[T]):
     def dict(self) -> Dict[str, Any]:
         return self._params.copy()
 
-    @property
-    def register(self) -> SmartRegister:
-        return self.__register
-
     def __call__(
         self,
         *args: Any,
@@ -260,135 +259,152 @@ class Smart(Generic[T]):
 
     def isin(
         self,
-        name: str,
+        key: str,
     ) -> bool:
-        """Checks if name is in dictionary.
+        """Checks if key is in dictionary.
 
         Args:
-            name: The key to be checked.
+            key: The key to be checked.
 
         Returns:
-            True if name is in dictionary, otherwise False.
+            True if key is in dictionary, otherwise False.
 
         """
         return dictutil.check_key_is_in(
-            key=name,
+            key=key,
             dictionary=self._params,
         )
 
     def get(
         self,
-        name: str,
+        key: str,
         default: Optional[Any] = ...,
     ) -> Any:
-        """Returns value of given name from dictionary.
+        """Returns value of given key from dictionary.
 
         Args:
-            name: The key of value.
+            key: The key of value.
             default: Value returned if key doesn't exist.
 
         Returns:
-            Value matched with given name.
+            Value matched with given key.
 
         Raises:
-            ValueError if name doesn't exist and default value not specified.
+            ValueError if key doesn't exist and default value not specified.
 
         """
-        dictionary, key = dictutil.find_nested(
+        dictionary, last_key = dictutil.find_nested(
             dictionary=self._params,
-            name=name,
+            key=key,
             required=default is ...,
         )
-        return dictionary.get(key, default)
+        return dictionary.get(last_key, default)
 
     def set(
         self,
-        name: str,
+        key: str,
         value: Any,
     ) -> Any:
-        """Sets new value of given name in dictionary.
+        """Sets new value of given key in dictionary.
 
         Args:
-            name: The key of value.
+            key: The key of value.
             value: Value to be set.
 
         Returns:
             The given value.
 
         """
-        dictionary, key = dictutil.find_nested(
+        dictionary, last_key = dictutil.find_nested(
             dictionary=self._params,
-            name=name,
+            key=key,
             set_mode=True,
         )
-        dictionary[key] = value
+        dictionary[last_key] = value
         return value
 
     def pop(
         self,
-        name: str,
+        key: str,
         default: Optional[Any] = ...,
     ) -> Any:
-        """Removes and returns value of given name from dictionary.
+        """Removes and returns value of given key from dictionary.
 
         Args:
-            name: The key of value.
+            key: The key of value.
             default: Value returned if key doesn't exist.
 
         Returns:
             Removed value.
 
         Raises:
-            ValueError if name doesn't exist and default value not specified.
+            ValueError if key doesn't exist and default value not specified.
 
         """
-        dictionary, key = dictutil.find_nested(
+        dictionary, last_key = dictutil.find_nested(
             dictionary=self._params,
-            name=name,
+            key=key,
             required=default is ...,
         )
-        return dictionary.pop(key, default)
+        return dictionary.pop(last_key, default)
 
     def map(
         self,
-        name: str,
+        key: str,
         function: Callable,
     ) -> Any:
-        """Applies value of given name to given function.
+        """Applies value of given key to given function.
 
         Args:
-            name: Name of value to be mapped.
+            key: Key of value to be mapped.
             function: A function to which map passes a value.
 
         Returns:
             Mapped value.
 
         Raises:
-            ValueError if name doesn't exist.
+            ValueError if key doesn't exist.
 
         """
-        dictionary, key = dictutil.find_nested(
+        dictionary, last_key = dictutil.find_nested(
             dictionary=self._params,
-            name=name,
+            key=key,
             required=True,
         )
-        dictionary[key] = value = function(dictionary[key])
+        dictionary[last_key] = value = function(dictionary[last_key])
         return value
 
+    def update(
+        self,
+        **kwargs: Any,
+    ) -> 'Smart':
+        """Updates existing items with given keyword arguments.
+
+        Args:
+            kwargs: New items to update.
+
+        Returns:
+            Smart instance.
+
+        """
+        return self.update_from(kwargs)
+
     def update_from(
         self,
         source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
-        name: Optional[str] = None,
+        source_key: Optional[str] = None,
+        target_key: Optional[str] = None,
         override: bool = True,
         required: bool = True,
     ) -> 'Smart':
-        """Inserts items from given source.
+        """Updates existing items from given source.
 
         Args:
-            source: Smart object, dictionary, list or path of items to insert.
-            name: Key of source dictionary to insert.
+            source: Smart object, dictionary, list or path of new items to update.
+            source_key: Key of source object to update.
+            target_key: Key of smart object to be updated.
             override: Whether to override existing items.
-            required: Whether the name is required to exist.
+            required: Whether the source_key is required to exist.
 
         Returns:
             Smart instance.
@@ -409,18 +425,22 @@ class Smart(Generic[T]):
         else:
             raise TypeError(f"Source type '{type(source)}' is not supported.")
 
-        if name is None:
+        if source_key is None:
             for key in smart.keys(flatten=True):
-                if override or not self.isin(key):
-                    self.set(key, smart.get(key))
+                new_key = strutil.join_keys(target_key, key) if target_key else key
+                if override or not self.isin(new_key):
+                    self.set(new_key, smart.get(key))
         else:
             try:
                 self.update_from(
-                    source=smart.get(name, default=... if required else dict()),
+                    source=smart.get(source_key, default=... if required else dict()),
+                    target_key=target_key,
                     override=override,
                 )
             except Exception as e:
-                raise RuntimeError(f"Cannot update with source name '{name}'. " + ' '.join(e.args))
+                raise RuntimeError(
+                    f"Cannot update with source key '{source_key}'. " + ' '.join(e.args)
+                )
 
         return self
 
@@ -428,13 +448,13 @@ class Smart(Generic[T]):
     def load_from(
         cls,
         source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
-        name: Optional[str] = None,
+        key: Optional[str] = None,
     ) -> Any:
         """Loads object from the given source.
 
         Args:
             source: Smart object, dictionary, list or path of object to load.
-            name: Key of source dictionary.
+            key: Key of source dictionary.
 
         Returns:
             Instance of loaded source.
@@ -443,36 +463,36 @@ class Smart(Generic[T]):
             TypeError if given source is not supported.
 
         """
-        return cls().update_from(source=source, name=name).init()
+        return cls().update_from(source=source, source_key=key).init()
 
     def init(
         self,
-        name: Optional[str] = None,
+        key: Optional[str] = None,
         persist: bool = True,
     ) -> Any:
-        """Instantiates dictionary with given name.
+        """Instantiates dictionary with given key.
 
         Args:
-            name: Key of dictionary to be instantiated.
+            key: Key of dictionary to be instantiated.
             persist: Whether to keep instantiated object in dictionary.
 
         Returns:
             Object of instantiated class.
 
         """
-        if name is None:
+        if key is None:
             obj = self._init_object(
                 obj=self._params,
                 location=self._location,
             )
         else:
             obj = self._init_object(
-                obj=self.get(name),
-                location=strutil.join_keys(self._location, name),
+                obj=self.get(key),
+                location=strutil.join_keys(self._location, key),
             )
 
             if persist:
-                return self.set(name, obj)
+                return self.set(key, obj)
 
         return obj
 
@@ -692,8 +712,8 @@ class Smart(Generic[T]):
                 kwargs=kwargs,
             )
 
-        if name in self.__register.origins:
-            name = self.__register.origins[name]
+        if name in self.register.origins:
+            name = self.register.origins[name]
         elif self.allow_only_registered_classes:
             raise ObjectNotRegistered(name, location)
 
@@ -785,22 +805,19 @@ class Smart(Generic[T]):
             annotation = param.annotation
             default = param.default
 
-            if not (i == 0 and annotation is param.empty and default is param.empty) or kind in (
-                param.POSITIONAL_OR_KEYWORD,
-                param.KEYWORD_ONLY,
+            if not (default is not param.empty and skip_default) and (
+                not (i == 0 and annotation is param.empty and default is param.empty)
+                or kind in (param.POSITIONAL_OR_KEYWORD, param.KEYWORD_ONLY)
             ):
-                if annotation is Smart or isinstance(default, Smart) and default.type is dict:
+                if annotation is Smart:
                     representation[name] = {
                         self.keyword: Smart.__name__,
                     }
-                elif get_origin(annotation) is Smart or isinstance(default, Smart):
-                    if isinstance(default, Smart):
-                        param_type = default.type
-                    else:
-                        param_type, *_ = get_args(annotation)
+                elif get_origin(annotation) is Smart:
+                    param_type, *_ = get_args(annotation)
 
                     keyword = inspect.formatannotation(param_type)
-                    keyword = self.__register.aliases.get(keyword, keyword)
+                    keyword = self.register.aliases.get(keyword, keyword)
                     keyword = strutil.join_objects(keyword, Option.SMART.value)
 
                     representation[name] = {
@@ -810,16 +827,14 @@ class Smart(Generic[T]):
                             skip_default=skip_default,
                         ),
                     }
-                elif default is not param.empty and skip_default:
-                    continue
-                elif default is None or isinstance(default, (bool, float, int, str)):
+                elif isinstance(default, (bool, float, int, str, type(None))):
                     representation[name] = default
                 elif annotation is not param.empty and isinstance(annotation, type):
                     if annotation in (bool, float, int, str):
                         representation[name] = annotation.__name__ + self.missing_value
                     else:
                         keyword = inspect.formatannotation(annotation)
-                        keyword = self.__register.aliases.get(keyword, keyword)
+                        keyword = self.register.aliases.get(keyword, keyword)
                         representation[name] = {
                             self.keyword: keyword,
                             **self._object_representation(
