@@ -134,20 +134,11 @@ class TestSmartRepresentationCase(IntegrationCase):
 
     def test_object_representation__with_defaults(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
-        class_child_name = f"{ClassChild.__module__}.{ClassChild.__qualname__}"
         expected = {
             'vanilla_cls': {'class': class_name, 'arg1': 'str???', 'arg2': 5},
             'smart_cls': {'class': f'{class_name}:Smart', 'arg1': 'str???', 'arg2': 5},
             'smart': {'class': 'Smart'},
             'unknown': '???',
-            'smart_cls_with_default': {
-                'class': f'{class_child_name}:Smart',
-                'arg1': 'str???',
-                'arg2': 5,
-            },
-            'smart_cls_with_only_default_generic': {
-                'class': 'Smart',
-            },
         }
 
         actual = self.smart._object_representation(ClassComposition, skip_default=False)
@@ -156,19 +147,11 @@ class TestSmartRepresentationCase(IntegrationCase):
 
     def test_object_representation__without_defaults(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
-        class_child_name = f"{ClassChild.__module__}.{ClassChild.__qualname__}"
         expected = {
             'vanilla_cls': {'class': class_name, 'arg1': 'str???'},
             'smart_cls': {'class': f'{class_name}:Smart', 'arg1': 'str???'},
             'smart': {'class': 'Smart'},
             'unknown': '???',
-            'smart_cls_with_default': {
-                'class': f'{class_child_name}:Smart',
-                'arg1': 'str???',
-            },
-            'smart_cls_with_only_default_generic': {
-                'class': 'Smart',
-            },
         }
 
         actual = self.smart._object_representation(ClassComposition, skip_default=True)
@@ -185,14 +168,6 @@ class TestSmartRepresentationCase(IntegrationCase):
             'smart_cls': {'class': 'Parent:Smart', 'arg1': 'str???', 'arg2': 5},
             'smart': {'class': 'Smart'},
             'unknown': '???',
-            'smart_cls_with_default': {
-                'class': 'Child:Smart',
-                'arg1': 'str???',
-                'arg2': 5,
-            },
-            'smart_cls_with_only_default_generic': {
-                'class': 'Smart',
-            },
         }
 
         actual = self.smart._object_representation(ClassComposition, skip_default=False)
